//@line 36 "/builds/slave/rel-m-beta-lnx-mb-rpk-3/mozilla-beta/ga-IE/mobile/mobile-l10n.js"

//@line 38 "/builds/slave/rel-m-beta-lnx-mb-rpk-3/mozilla-beta/ga-IE/mobile/mobile-l10n.js"

pref("general.useragent.locale", "ga-IE");
